# SEON JavaScript SDK v5

To successfully utilize this library, you must have a SEON account set up. (https://seon.io)

## Installation

You can either use one of our CDNs, or this npm package to load the SDK.

### CDN

It is preferred to use one of our CDNs directly, because this way you will always receive the latest version.

```html
<script src="https://cdn.seondf.com/js/v5/agent.js"></script>
<!-- or -->
<script src="https://cdn.deviceinf.com/js/v5/agent.js"></script>
<!-- or -->
<script src="https://cdn.getdeviceinf.com/js/v5/agent.js"></script>
```

Then in your JavaScript you can use the `window.seon` object:

```javascript
window.seon.config({
  host: "seondf.com",
  session_id: "[session_id]",
  audio_fingerprint: true,
  canvas_fingerprint: true,
  webgl_fingerprint: true,
  onSuccess: function(message) {
    console.log("success", message);
  },
  onError: function(message) {
    console.log("error", message);
  }
});
```

For more information about the config options, please visit https://docs.seon.io/api-reference#javascript-agent-v5 .

After successful configuration, you can collect the device fingerprint with the `getBase64Session` function:

```javascript
window.seon.getBase64Session().then((encryptedPayload) => {
    console.log(encryptedPayload);
});
```

This will give you the collected device info in an encrypted format. You can not decrypt it yourself,
you have to send it as the `session` parameter to SEON's proprietary Fraud API (see https://docs.seon.io/api-reference#fraud-api).
The Fraud API will return the device fingerprint in the `device_details` field.

### NPM

**Note that with this method you will have to keep the package updated yourself to include our latest features and bugfixes.**

```bash
npm install @seontechnologies/seon-javascript-sdk
# or
yarn add @seontechnologies/seon-javascript-sdk
```

Usage:

```javascript
import seon from 'seon-javascript-sdk';
// or
// const seon = require('seon-javascript-sdk');

seon.config({
  host: "seondf.com",
  session_id: "[session_id]",
  audio_fingerprint: true,
  canvas_fingerprint: true,
  webgl_fingerprint: true,
  onSuccess: function(message) {
    console.log("success", message);
  },
  onError: function(message) {
    console.log("error", message);
  }
});

seon.getBase64Session().then((encryptedPayload) => {
    console.log(encryptedPayload);
});
```

For more information, visit https://docs.seon.io/api-reference#javascript-agent-v5 .
